import codecommit = require('@aws-cdk/aws-codecommit');
import codepipeline = require('@aws-cdk/aws-codepipeline');
/**
 * Construction properties of the {@link CodeCommitSourceAction CodeCommit source CodePipeline Action}.
 */
export interface CodeCommitSourceActionProps extends codepipeline.CommonActionProps {
    /**
     * The name of the source's output artifact.
     * Output artifacts are used by CodePipeline as inputs into other actions.
     *
     * @default a name will be auto-generated
     */
    readonly outputArtifactName?: string;
    /**
     * @default 'master'
     */
    readonly branch?: string;
    /**
     * Whether AWS CodePipeline should poll for source changes.
     * If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
     *
     * @default false
     */
    readonly pollForSourceChanges?: boolean;
    /**
     * The CodeCommit repository.
     */
    readonly repository: codecommit.IRepository;
}
/**
 * CodePipeline Source that is provided by an AWS CodeCommit repository.
 */
export declare class CodeCommitSourceAction extends codepipeline.SourceAction {
    private readonly props;
    constructor(props: CodeCommitSourceActionProps);
    protected bind(info: codepipeline.ActionBind): void;
}
