import codepipeline = require('@aws-cdk/aws-codepipeline');
import ecr = require('@aws-cdk/aws-ecr');
/**
 * Construction properties of {@link EcrSourceAction}.
 */
export interface EcrSourceActionProps extends codepipeline.CommonActionProps {
    /**
     * The image tag that will be checked for changes.
     *
     * @default 'latest'
     */
    readonly imageTag?: string;
    /**
     * The name of the source's output artifact.
     * CfnOutput artifacts are used by CodePipeline as inputs into other actions.
     *
     * @default a name will be auto-generated
     */
    readonly outputArtifactName?: string;
    /**
     * The repository that will be watched for changes.
     */
    readonly repository: ecr.IRepository;
}
/**
 * The ECR Repository source CodePipeline Action.
 */
export declare class EcrSourceAction extends codepipeline.SourceAction {
    private readonly props;
    constructor(props: EcrSourceActionProps);
    protected bind(info: codepipeline.ActionBind): void;
}
